package de.intevation.flys.exports;

import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;

import org.apache.log4j.Logger;

import au.com.bytecode.opencsv.CSVWriter;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.WINFOArtifact;
import de.intevation.flys.artifacts.model.WQKms;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ComputedDischargeCurveExporter extends AbstractExporter {

    /** The logger used in this exporter.*/
    private static Logger logger =
        Logger.getLogger(ComputedDischargeCurveExporter.class);

    public static final String CSV_W_HEADER =
        "export.computed.discharge.curve.csv.header.w";

    public static final String CSV_Q_HEADER =
        "export.computed.discharge.curve.csv.header.q";

    public static final String DEFAULT_CSV_W_HEADER  = "W [NN + m]";
    public static final String DEFAULT_CSV_Q_HEADER  = "Q [m³/s]";


    protected List<WQKms> data;


    public void init(Document request, OutputStream out, CallContext context) {
        logger.debug("ComputedDischargeCurveExporter.init");

        super.init(request, out, context);

        this.data = new ArrayList<WQKms>();
    }


    protected void addData(Artifact artifact) {
        WINFOArtifact winfoArtifact = (WINFOArtifact) artifact;
        data.add(winfoArtifact.getComputedDischargeCurveData());
    }


    protected void writeCSVData(CSVWriter writer) {
        logger.info("ComputedDischargeCurveExporter.writeData");

        writeCSVHeader(writer);

        double[] res = new double[3];

        for (WQKms wqkms: data) {
            int size = wqkms.size();

            for (int i = 0; i < size; i++) {
                res = wqkms.get(i, res);

                writer.writeNext(new String[] {
                    Double.toString(res[0]),
                    Double.toString(res[1])
                });
            }
        }
    }


    protected void writeCSVHeader(CSVWriter writer) {
        logger.debug("ComputedDischargeCurveExporter.writeCSVHeader");

        writer.writeNext(new String[] {
            msg(CSV_W_HEADER, DEFAULT_CSV_W_HEADER),
            msg(CSV_Q_HEADER, DEFAULT_CSV_Q_HEADER)
        });
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
